@@ -61,6 +61,10 @@ drag_dest_drag_data_received(GtkTreeDragDest *drag_dest, GtkTreePath *dest,
         src_model != tree_model) {
         return FALSE;
     }
+    if (gtk_tree_path_compare(src_path, dest) == 0) {
+        gtk_tree_path_free(src_path);
+        return FALSE;
+    }
     if (gtk_tree_model_get_iter(src_model, &iter, src_path)) {
         gtk_tree_model_get(tree_model, &iter, COLUMN_ENTRY, &target, -1);
     }
@@ -103,6 +107,9 @@ drag_dest_drag_data_received(GtkTreeDragDest *drag_dest, GtkTreePath *dest,
         }
     }
     gtk_tree_path_free(up);
+    if (previous == target) {
+        return FALSE;
+    }
     window = GPASS_WINDOW(g_object_get_data(G_OBJECT(tree_model), "window"));
     gpass_entry_tree_push_move_command(window, target, parent, previous);
     return TRUE;
