@@ -139,7 +139,7 @@ lock_timeout_func(gpointer data)
                                         "model", app, NULL);
     GPassViewResult result;
     GError *error;
-    
+
     gtk_widget_hide(GPASS_VIEW(self)->window);
     gtk_window_iconify(GTK_WINDOW(GPASS_VIEW(lock)->window));
     error = gpass_view_run(GPASS_VIEW(lock), &result);
@@ -147,7 +147,13 @@ lock_timeout_func(gpointer data)
         gpass_error_show_and_exit(error);
     }
     g_object_unref(lock);
-    gtk_widget_show(GPASS_VIEW(self)->window);
+    if (result == GPASS_LOCK_RESULT_CLOSE) {
+        GPASS_VIEW(self)->result = GPASS_VIEW_RESULT_SUCCEED;
+        gpass_view_shutdown_main_loop(GPASS_VIEW(self));
+    }
+    else {
+        gtk_widget_show(GPASS_VIEW(self)->window);
+    }
     return TRUE;
 }
 
